@@ -19,8 +19,9 @@ def badcommand(msg):
     """(Parsing error) print to stderr and quit."""
     fatalerror(msg, label='usage', code=2)
 
+
 class doing:
-    """``with`` wrapper for messages like "Doing X... Done.\""""
+    """`with` wrapper for messages like "Doing X... Done.\""""
 
     done = ' Done.'
 
@@ -28,14 +29,15 @@ class doing:
         self.msg = msg
 
     def __enter__(self):
-        echo(self.msg + '...', width=72 - len(self.done), end='', flush=True)
+        width = 72 - len(self.done)
+        echo(self.msg + '...', width=width, end='', flush=True)
 
     def __exit__(self, exc_type, exc_value, traceback):
         echo(self.done)
 
 
 def echo(text, width=72, **kwargs):
-    """``print()``, but wraps long lines, preserving the initial indent."""
+    """`print()`, but wraps long lines, preserving the initial indent."""
     for line in str(text).splitlines():
         if len(line) > width:
             indent = re.match('\\s*', line)[0]
@@ -45,7 +47,7 @@ def echo(text, width=72, **kwargs):
 
 
 def envnotfound(env):
-    """``'Env "my-venv" not found. Did you mean "./my-venv"?'``"""
+    """`'Env "my-venv" not found. Did you mean "./my-venv"?'`"""
     msg = f'Env "{env}" not found.'
     if arg_is_name(env) and Path(env).exists():
         msg += f'\nDid you mean "./{env}"?'
@@ -75,9 +77,9 @@ def main(args=None):
 
 
 def selectnpop(dic, lis, i=0):
-    """If ``dic[lis[i]]`` exists, return it after popping ``lis[i]``.
+    """If `dic[lis[i]]` exists, return it after popping `lis[i]`.
 
-    Falls back on ``dic[None]``.
+    Falls back on `dic[None]`.
     """
     try:
         selection = dic[lis[i]]
@@ -88,7 +90,7 @@ def selectnpop(dic, lis, i=0):
 
 
 def tilde(path):
-    """Inverse of ``Path.expanduser()``. For display purposes."""
+    """Inverse of `Path.expanduser()`. For display purposes."""
     try:
         rel = path.relative_to(Path.home())
     except ValueError:
@@ -100,6 +102,8 @@ def tilde(path):
 
 def write_path_file(new_vnv_path):
     """Overwrite path.txt."""
+    path_file.parent.mkdir(parents=True, exist_ok=True)
+    path_file.touch(exist_ok=True)
     path_file.write_text('\n'.join(new_vnv_path))
 
 
@@ -226,12 +230,13 @@ To create "my-venv" in the current directory, make sure to use:
         if not self.cli.allargs:
             badcommand(expectedgot('1 or more', 0))
         env = self.cli.allargs[0]
-        if arg_is_name(env):
-            env = str(internal_dir / env)
         try:
             import virtualenv
         except ImportError:
             fatalerror('Cannot access virtualenv. Is it installed?')
+        if arg_is_name(env):
+            env = str(internal_dir / env)
+            internal_dir.mkdir(parents=True, exist_ok=True)
         # Account for the possiblility of a -- coming before ENV.
         subsequent_args = self.cli.raw_args[2 if self.cli.mixedargs else 3:]
         with doing(f'Creating virtualenv at "{env}"'):
@@ -264,7 +269,7 @@ Use "vnv which ENV" to confirm which folder that is."""
 
 
 class ListCommand(Command):
-    """List installed envs"""
+    """List known envs"""
 
     name = 'list'
     long_help = """\
