@@ -13,14 +13,14 @@ class Betterment:
         return True
 
     def get(self, index, default=None):
-        """Like ``dict.get``."""
+        """Like `dict.get`."""
         try:
             return self[index]  # pylint: disable=unsubscriptable-object
         except IndexError:
             return default
 
     def safepop(self, index=-1, default=None):
-        """Like ``dict.pop``."""
+        """Like `dict.pop`."""
         try:
             return self.pop(index)
         except IndexError:
@@ -30,21 +30,15 @@ class Betterment:
 class BetterList(list, Betterment):
     """List with better popping features."""
 
+    def __repr__(self):
+        return f'{type(self).__name__}({list.__repr__(self)})'
+
 
 class ChainList(Betterment):
     """List-like access object for a series of sub-lists."""
 
-    def _access(self, key):
-        """Find ``link`` and ``i`` such that ``self[key]`` <-> ``link[i]``."""
-        if key < 0:
-            key += len(self)
-        if key >= 0:
-            index = key
-            for link in self.links:
-                if index < len(link):
-                    return link, index
-                index -= len(link)
-        raise IndexError(f'{type(self).__name__} index out of range')
+    def __init__(self, *links):
+        self.links = list(links)
 
     def __contains__(self, key):
         return any(key in link for link in self.links)
@@ -57,9 +51,6 @@ class ChainList(Betterment):
         link, index = self._access(key)
         return link[index]
 
-    def __init__(self, *links):
-        self.links = list(links)
-
     def __iter__(self):
         for link in self.links:
             yield from link
@@ -75,6 +66,18 @@ class ChainList(Betterment):
         link, index = self._access(key)
         link[index] = value
 
+    def _access(self, key):
+        """Find `link` and `i` such that `self[key]` <-> `link[i]`."""
+        if key < 0:
+            key += len(self)
+        if key >= 0:
+            index = key
+            for link in self.links:
+                if index < len(link):
+                    return link, index
+                index -= len(link)
+        raise IndexError(f'{type(self).__name__} index out of range')
+
     def copy(self):
         return type(self)(*self.links)
 
