@@ -10,24 +10,22 @@ vnv_cache = 'VNV_CACHE'
 
 
 def arg_is_name(arg):
-    """Is ``arg`` a simple name?."""
+    """Is `arg` a simple name?."""
     return arg != '..' and PurePath(arg).name == arg
 
 
-def make_home():
-    """Make sure ~/.vnv is present."""
-    internal_dir.mkdir(parents=True, exist_ok=True)
-    path_file.touch(exist_ok=True)
-
-
 class PathManager:
     """Path resolution manager."""
 
     def __init__(self, shell):
         self.shell = shell
-        make_home()
-        path_lines = path_file.read_text().splitlines()
-        self.raw = tuple(filter(None, map(str.strip, path_lines)))
+        try:
+            path_text = path_file.read_text()
+        except OSError:
+            self.raw = ()
+        else:
+            path_lines = path_text.splitlines()
+            self.raw = tuple(filter(None, map(str.strip, path_lines)))
         self.path = (internal_dir, *map(Path, self.raw))
 
     def get_actfile(self, path):
@@ -51,14 +49,14 @@ class PathManager:
             pass
 
     def lookup(self, env):
-        """Get the activate file for ``env``."""
+        """Get the activate file for `env`."""
         if arg_is_name(env):
             # If there is an exact match by name, return it.
             for path_entry in self.path:
                 actfile = self.get_actfile(path_entry / env)
                 if actfile is not None:
                     return actfile
-            # Otherwise, return the first env ``env`` is short for.
+            # Otherwise, return the first env `env` is short for.
             env = os.path.normcase(env)
             for path_entry in self.path:
                 for possible_match in self.get_envs(path_entry):
